linkedin_signin_plus library

Classes

LinkedInAccessToken
When you get authorization code, you need to exchange to get access token Expires in is time, when your access token will be invalid
LinkedInConfig
LinkedIn configuration class
LinkedInLocale
LinkedIn Locale information
LinkedinSigninPlus
LinkedInUserModel
LinkedIn User information

Typedefs

OnError = void Function(HttpResponseException error)
Callbacks for LinkedIn Login error which returns HttpResponseException
OnGetAuthToken = void Function(LinkedInAccessToken data)
Callbacks for LinkedIn Login which returns LinkedInAccessToken
OnGetUserProfile = void Function(LinkedInUserModel user)
Callbacks for LinkedIn Login which returns LinkedInUserModel